==> protobuf-21.12-2-aarch64.pkg.tar.xz: usr/lib/cmake/protobuf/protobuf-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "protobuf::libprotobuf-lite" for configuration "None"
set_property(TARGET protobuf::libprotobuf-lite APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::libprotobuf-lite PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libprotobuf-lite.so.3.21.12.0"
  IMPORTED_SONAME_NONE "libprotobuf-lite.so.32"
  )

list(APPEND _cmake_import_check_targets protobuf::libprotobuf-lite )
list(APPEND _cmake_import_check_files_for_protobuf::libprotobuf-lite "${_IMPORT_PREFIX}/lib/libprotobuf-lite.so.3.21.12.0" )

# Import target "protobuf::libprotobuf" for configuration "None"
set_property(TARGET protobuf::libprotobuf APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::libprotobuf PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libprotobuf.so.3.21.12.0"
  IMPORTED_SONAME_NONE "libprotobuf.so.32"
  )

list(APPEND _cmake_import_check_targets protobuf::libprotobuf )
list(APPEND _cmake_import_check_files_for_protobuf::libprotobuf "${_IMPORT_PREFIX}/lib/libprotobuf.so.3.21.12.0" )

# Import target "protobuf::libprotoc" for configuration "None"
set_property(TARGET protobuf::libprotoc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::libprotoc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "protobuf::libprotobuf"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libprotoc.so.3.21.12.0"
  IMPORTED_SONAME_NONE "libprotoc.so.32"
  )

list(APPEND _cmake_import_check_targets protobuf::libprotoc )
list(APPEND _cmake_import_check_files_for_protobuf::libprotoc "${_IMPORT_PREFIX}/lib/libprotoc.so.3.21.12.0" )

# Import target "protobuf::protoc" for configuration "None"
set_property(TARGET protobuf::protoc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::protoc PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/protoc-3.21.12.0"
  )

list(APPEND _cmake_import_check_targets protobuf::protoc )
list(APPEND _cmake_import_check_files_for_protobuf::protoc "${_IMPORT_PREFIX}/bin/protoc-3.21.12.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> protobuf-23.4-1-aarch64.pkg.tar.xz: usr/lib/cmake/protobuf/protobuf-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "protobuf::libprotobuf-lite" for configuration "None"
set_property(TARGET protobuf::libprotobuf-lite APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::libprotobuf-lite PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libprotobuf-lite.so.23.4.0"
  IMPORTED_SONAME_NONE "libprotobuf-lite.so.23"
  )

list(APPEND _cmake_import_check_targets protobuf::libprotobuf-lite )
list(APPEND _cmake_import_check_files_for_protobuf::libprotobuf-lite "${_IMPORT_PREFIX}/lib/libprotobuf-lite.so.23.4.0" )

# Import target "protobuf::libprotobuf" for configuration "None"
set_property(TARGET protobuf::libprotobuf APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::libprotobuf PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libprotobuf.so.23.4.0"
  IMPORTED_SONAME_NONE "libprotobuf.so.23"
  )

list(APPEND _cmake_import_check_targets protobuf::libprotobuf )
list(APPEND _cmake_import_check_files_for_protobuf::libprotobuf "${_IMPORT_PREFIX}/lib/libprotobuf.so.23.4.0" )

# Import target "protobuf::libprotoc" for configuration "None"
set_property(TARGET protobuf::libprotoc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::libprotoc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "protobuf::libprotobuf"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libprotoc.so.23.4.0"
  IMPORTED_SONAME_NONE "libprotoc.so.23"
  )

list(APPEND _cmake_import_check_targets protobuf::libprotoc )
list(APPEND _cmake_import_check_files_for_protobuf::libprotoc "${_IMPORT_PREFIX}/lib/libprotoc.so.23.4.0" )

# Import target "protobuf::protoc" for configuration "None"
set_property(TARGET protobuf::protoc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(protobuf::protoc PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/protoc-23.4.0"
  )

list(APPEND _cmake_import_check_targets protobuf::protoc )
list(APPEND _cmake_import_check_files_for_protobuf::protoc "${_IMPORT_PREFIX}/bin/protoc-23.4.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
